@@ -79,6 +79,7 @@ from functools import update_wrapper
 from typing import Optional, Tuple, Union, Mapping, Any, List, Iterable
 
 from ..lib.loader import resolve, EntryNotFound
+from ..lib.frame import Chunk
 
 
 class PythonExpression:
@@ -289,6 +290,12 @@ class TooLazy(Exception):
     pass
 
 
+class VariableMissing(RuntimeError):
+    def __init__(self, name):
+        super().__init__(F'The variable {name} is not defined.')
+        self.name = name
+
+
 class LazyEvaluation:
     """
     Empty parent class for any unit that throws `refinery.lib.argformats.TooLazy`.
@@ -542,6 +549,39 @@ class DelayedBinaryArgument(DelayedArgument):
         bounds = sliceobj(region)
         return extract
 
+    def _interpret_variable(self, name: str, obj: Any):
+        if isinstance(obj, (bytes, bytearray, memoryview)):
+            return obj
+        if isinstance(obj, str):
+            return utf8(obj)
+        raise ValueError(F'The meta variable {name} is of type {type(obj).__name__} and no conversion to bytes is known.')
+
+    @handler.register('var', final=True)
+    def meta_get(self, name: str) -> bytes:
+        """
+        Contains the value of a meta variable. The variable remains attached to the chunk.
+        """
+        def extract(data: Chunk):
+            try:
+                result = data.meta[name]
+            except KeyError as K:
+                raise VariableMissing(name) from K
+            return self._interpret_variable(name, result)
+        return extract
+
+    @handler.register('pop', final=True)
+    def meta_pop(self, name: str) -> bytes:
+        """
+        Extracts data from a meta field in a chunk.
+        """
+        def extract(data: Chunk):
+            try:
+                result = data.meta.pop(name)
+            except KeyError as K:
+                raise VariableMissing(name) from K
+            return self._interpret_variable(name, result)
+        return extract
+
 
 def multibin(expression: Union[str, bytes, bytearray]) -> Union[bytes, DelayedBinaryArgument]:
     """
