@@ -42,7 +42,7 @@ from argparse import (
     ZERO_OR_MORE
 )
 
-from ..lib.argformats import pending, manifest, multibin, number, sliceobj
+from ..lib.argformats import pending, manifest, multibin, number, sliceobj, VariableMissing
 from ..lib.tools import terminalfit, get_terminal_size, documentation, lookahead, autoinvoke, skipfirst, isbuffer
 from ..lib.frame import Framed, Chunk
 
@@ -208,7 +208,7 @@ class arg(Argument):
         """
         cnames = [c.name for c in choices]
         return arg(*args, group=group, help=help.format(choices=', '.join(cnames)),
-            metavar=choices.__name__, dest=dest, choices=cnames, type=choices.__getitem__)
+            metavar=choices.__name__, dest=dest, choices=[c.value for c in choices], type=choices.__getitem__)
 
     @staticmethod
     def help(msg: str) -> Argument:
@@ -259,7 +259,7 @@ class arg(Argument):
         """
 
         def get_argp_type(annotation_type):
-            if issubclass(annotation_type, (bytes, bytearray)):
+            if issubclass(annotation_type, (bytes, bytearray, memoryview)):
                 return multibin
             if issubclass(annotation_type, int):
                 return number
@@ -456,12 +456,14 @@ class Executable(type):
     def __new__(mcs, name, bases, nmspc, abstract=False):
         def normalize(operation: Callable[[Any, ByteString], Any]) -> Callable[[ByteString], Any]:
             def chunkify(item):
-                if not isinstance(item, dict):
-                    return Chunk(item)
-                return Chunk(item.pop('data', None), meta=item)
+                if isinstance(item, Chunk):
+                    return item
+                if isinstance(item, dict):
+                    return Chunk(item.pop('data', None), meta=item)
+                return Chunk(item)
 
             @wraps(operation)
-            def wrapped(self, data: ByteString) -> bytes:
+            def wrapped(self, data: ByteString) -> Union[Optional[ByteString], Iterable[ByteString]]:
                 if -self.args:
                     if not isinstance(data, bytearray):
                         data = bytearray(data)
@@ -473,9 +475,10 @@ class Executable(type):
                             data = dt(data)
                     except StopIteration:
                         pass
-                if inspect.isgeneratorfunction(operation):
+                if wrapped.chunked:
                     return (chunkify(r) for r in operation(self, data))
                 return chunkify(operation(self, data))
+            wrapped.chunked = inspect.isgeneratorfunction(operation)
             return wrapped
 
         nmspc.setdefault('__doc__', '')
@@ -724,9 +727,13 @@ class Unit(metaclass=Executable, abstract=True):
 
     def _exception_handler(self, exception: BaseException):
         if self.log_level <= LogLevel.DETACHED:
-            raise exception
+            raise
         elif isinstance(exception, RefineryCriticalException):
             self.log_warn(F'critical error, terminating: {exception}')
+            raise
+        elif isinstance(exception, VariableMissing):
+            self.log_warn('critical error:', exception)
+            raise RefineryCriticalException
         elif isinstance(exception, GeneratorExit):
             raise
         elif isinstance(exception, RefineryPartialResult):
@@ -735,8 +742,8 @@ class Unit(metaclass=Executable, abstract=True):
             elif not self.log_warn(F'error, partial result returned: {exception}'):
                 raise exception
             return exception.partial
-
-        self.log_warn(F'unexpected exception of type {exception.__class__.__name__}; {exception!s}')
+        else:
+            self.log_warn(F'unexpected exception of type {exception.__class__.__name__}; {exception!s}')
 
         if self.log_debug():
             import traceback
@@ -747,15 +754,9 @@ class Unit(metaclass=Executable, abstract=True):
             self._chunks = iter(self._framehandler)
         while True:
             try:
-                result = next(self._chunks)
-            except Exception as E:
-                if isinstance(E, StopIteration):
-                    raise
-                result = self._exception_handler(E)
-                if result is None:
-                    raise StopIteration from E
-            if not isinstance(result, BaseException):
-                return result
+                return next(self._chunks)
+            except RefineryCriticalException as R:
+                raise StopIteration from R
 
     @property
     def _framehandler(self) -> Framed:
@@ -764,7 +765,7 @@ class Unit(metaclass=Executable, abstract=True):
 
         op = self.reverse if self.args.reverse else self.process
 
-        def normalized_action(data: bytearray) -> Iterable[bytes]:
+        def normalized_action(data: ByteString) -> Iterable[ByteString]:
             try:
                 result = op(data)
                 if inspect.isgenerator(result):
@@ -866,8 +867,9 @@ class Unit(metaclass=Executable, abstract=True):
             if (
                 self._framehandler.framebreak
                 or self._framehandler.unframed
-                and not last
                 and not chunk.endswith(B'\n')
+                and not self.args.squeeze
+                and not last
             ):
                 chunk += B'\n'
             try:
@@ -931,7 +933,7 @@ class Unit(metaclass=Executable, abstract=True):
             with io.BytesIO() as stdout:
                 return (stdin | self | stdout).getvalue()
 
-    def process(self, data: bytes) -> Union[Optional[bytes], Iterable[bytes]]:
+    def process(self, data: ByteString) -> Union[Optional[ByteString], Iterable[ByteString]]:
         """
         This routine is overridden by children of `refinery.units.Unit` to define how
         the unit processes a given chunk of binary data.
@@ -993,7 +995,7 @@ class Unit(metaclass=Executable, abstract=True):
             except TypeError: pass
             if isinstance(x, str):
                 return x
-            if isinstance(x, (bytes, bytearray)):
+            if isinstance(x, (bytes, bytearray, memoryview)):
                 import codecs
                 return codecs.decode(x, cls.codec, errors='backslashreplace')
             return str(x)
@@ -1014,11 +1016,14 @@ class Unit(metaclass=Executable, abstract=True):
         base = argp.add_argument_group('generic options')
 
         base.add_argument('-h', '--help', action='help', help='Show this help message and exit.')
-        base.set_defaults(reverse=False)
+        base.set_defaults(reverse=False, squeeze=False)
 
         if cls.is_reversible:
             base.add_argument('-R', '--reverse', action='store_true', help='Use the reverse operation.')
 
+        if cls.process.chunked or (cls.is_reversible and cls.reverse.chunked):
+            base.add_argument('-Z', '--squeeze', action='store_true', help='Fuse outputs, do not insert line breaks.')
+
         base.add_argument('-Q', '--quiet', action='store_true', help='Disables all log output.')
         base.add_argument('-0', '--devnull', action='store_true', help='Do not produce any output.')
         base.add_argument('-v', '--verbose', action='count', default=LogLevel.WARN,
@@ -1052,7 +1057,13 @@ class Unit(metaclass=Executable, abstract=True):
                             parser.order.append(self.dest)
                         return action(parser, ns, values, opt)
 
-                action.required = action.required and action.dest not in keywords
+                if action.dest in keywords:
+                    action.required = False
+                    if callable(getattr(action, 'type', None)):
+                        value = keywords[action.dest]
+                        if isinstance(value, str) and action.type is not str:
+                            keywords[action.dest] = action.type(keywords[action.dest])
+
                 return super()._add_action(RememberOrder())
 
             def _parse_optional(self, arg_string):
@@ -1142,6 +1153,15 @@ class Unit(metaclass=Executable, abstract=True):
         manually. This is a convenience feature which reduces code bloat when many parameters have to be
         forwarded, see e.g. `refinery.units.pattern.carve.carve` for an example.
         """
+        try:
+            if super.__init__.__func__ is Unit.__init__:
+                return super.__init__(**{
+                    name: value for name, value in keywords.items()
+                    if name != 'self' and not name.startswith('_')
+                })
+        except AttributeError:
+            pass
+
         return autoinvoke(super.__init__, keywords)
 
     @classmethod
@@ -1164,6 +1184,7 @@ class Unit(metaclass=Executable, abstract=True):
         unit.args._store(_argo=argp.order)
         unit.args.quiet = args.quiet
 
+        unit.args.squeeze = args.squeeze
         unit.args.dtiming = args.dtiming
         unit.args.nesting = args.nesting
         unit.args.reverse = args.reverse
@@ -1201,6 +1222,7 @@ class Unit(metaclass=Executable, abstract=True):
                 dtiming=False,
                 nesting=0,
                 reverse=False,
+                squeeze=False,
                 devnull=False,
                 verbose=LogLevel.DETACHED,
                 quiet=False,
